@@ -9,7 +9,7 @@ __docformat__ = 'restructuredtext en'
 import os, subprocess, re, sys, sysconfig
 from distutils.spawn import find_executable
 
-from setup import isosx, iswindows, is64bit, islinux
+from setup import isosx, iswindows, is64bit, islinux, ishaiku
 is64bit
 
 NMAKE = RC = msvc = MT = win_inc = win_lib = None
@@ -19,13 +19,9 @@ if iswindows:
     msvc.initialize()
     NMAKE = msvc.find_exe('nmake.exe')
     RC = msvc.find_exe('rc.exe')
-    SDK = os.environ.get('WINSDK', r'C:\Program Files\Microsoft SDKs\Windows\v7.0')
+    MT = msvc.find_exe('mt.exe')
     win_inc = os.environ['include'].split(';')
     win_lib = os.environ['lib'].split(';')
-    for p in win_inc:
-        if 'SDK' in p:
-            MT = os.path.join(os.path.dirname(p), 'bin', 'mt.exe')
-    MT = os.path.join(SDK, 'Bin', 'mt.exe')
 
 QMAKE = 'qmake'
 for x in ('qmake-qt5', 'qt5-qmake', 'qmake'):
@@ -37,7 +33,7 @@ QMAKE = os.environ.get('QMAKE', QMAKE)
 
 PKGCONFIG = find_executable('pkg-config')
 PKGCONFIG = os.environ.get('PKG_CONFIG', PKGCONFIG)
-if islinux and not PKGCONFIG:
+if (islinux or ishaiku) and not PKGCONFIG:
     raise SystemExit('Failed to find pkg-config on your system. You can use the environment variable PKG_CONFIG to point to the pkg-config executable')
 
 def run_pkgconfig(name, envvar, default, flag, prefix):
@@ -88,7 +84,7 @@ pyqt['sip_bin'] = os.environ.get('SIP_BIN', 'sip')
 from PyQt5.QtCore import PYQT_CONFIGURATION
 pyqt['sip_flags'] = PYQT_CONFIGURATION['sip_flags']
 def get_sip_dir():
-    q = os.environ.get('SIP_DIR', sys.prefix if iswindows else os.path.join(sys.prefix, 'share', 'sip'))
+    q = os.environ.get('SIP_DIR', os.path.join(sys.prefix, 'share', 'sip') if iswindows else os.path.join(sys.prefix, 'share', 'sip'))
     for x in ('', 'Py2-PyQt5', 'PyQt5', 'sip/PyQt5'):
         base = os.path.join(q, x)
         if os.path.exists(os.path.join(base, 'QtWidgets')):
@@ -97,8 +93,8 @@ def get_sip_dir():
 pyqt['pyqt_sip_dir'] = get_sip_dir()
 pyqt['sip_inc_dir'] = os.environ.get('SIP_INC_DIR', sysconfig.get_path('include'))
 
-glib_flags = subprocess.check_output([PKGCONFIG, '--libs', 'glib-2.0']).strip() if islinux else ''
-fontconfig_flags = subprocess.check_output([PKGCONFIG, '--libs', 'fontconfig']).strip() if islinux else ''
+glib_flags = subprocess.check_output([PKGCONFIG, '--libs', 'glib-2.0']).strip() if islinux or ishaiku else ''
+fontconfig_flags = subprocess.check_output([PKGCONFIG, '--libs', 'fontconfig']).strip() if islinux or ishaiku else ''
 qt_inc = pyqt['inc']
 qt_lib = pyqt['lib']
 ft_lib_dirs = []
@@ -113,56 +109,27 @@ icu_lib_dirs = []
 zlib_inc_dirs = []
 zlib_lib_dirs = []
 openssl_inc_dirs, openssl_lib_dirs = [], []
-icu_libs = ['icudata', 'icui18n', 'icuuc', 'icuio']
 ICU = sw = ''
 
-QT_DLLS = ['Qt5' + x for x in (
-'Core', 'Gui',  'OpenGL', 'Network', 'PrintSupport', 'Positioning', 'Sensors', 'Sql', 'Svg',
-'WebKit', 'WebKitWidgets', 'Widgets',  'Multimedia', 'MultimediaWidgets', 'Xml',  # 'XmlPatterns',
-)]
-QT_PLUGINS = ('imageformats', 'audio', 'iconengines', 'mediaservice', 'platforms', 'playlistformats', 'printsupport', 'sqldrivers')
-if islinux:
-    # platformthemes cause crashes in Ubuntu
-    QT_PLUGINS += ('platforminputcontexts', 'generic',)
-
-PYQT_MODULES = ('Qt', 'QtCore', 'QtGui', 'QtNetwork',  # 'QtMultimedia', 'QtMultimediaWidgets',
-                'QtPrintSupport', 'QtSensors', 'QtSvg', 'QtWebKit', 'QtWebKitWidgets', 'QtWidgets')
-QT_FRAMEWORKS = []
-
-
 if iswindows:
-    icu_libs = ['icudt', 'icuin', 'icuuc', 'icuio']
-    QT_DLLS += ['Qt5WinExtras']
-    QT_DLLS = {x + '.dll' for x in QT_DLLS}
-    PYQT_MODULES += ('QtWinExtras',)
-    PYQT_MODULES = {x + '.pyd' for x in PYQT_MODULES}
     prefix  = sw = os.environ.get('SW', r'C:\cygwin64\home\kovid\sw')
     sw_inc_dir  = os.path.join(prefix, 'include')
     sw_lib_dir  = os.path.join(prefix, 'lib')
-    ICU = os.environ.get('ICU_DIR', os.path.join(prefix, 'private', 'icu'))
-    icu_inc_dirs = [os.path.join(ICU, 'source', 'common'), os.path.join(ICU,
-        'source', 'i18n')]
-    icu_lib_dirs = [os.path.join(ICU, 'source', 'lib')]
-    SSL = os.environ.get('OPENSSL_DIR', os.path.join(prefix, 'private', 'openssl'))
-    openssl_inc_dirs = [os.path.join(SSL, 'include')]
-    openssl_lib_dirs = [os.path.join(SSL, 'lib')]
+    icu_inc_dirs = [sw_inc_dir]
+    icu_lib_dirs = [sw_lib_dir]
+    openssl_inc_dirs = [sw_inc_dir]
+    openssl_lib_dirs = [sw_lib_dir]
     sqlite_inc_dirs = [sw_inc_dir]
-    chmlib_inc_dirs = consolidate('CHMLIB_INC_DIR', os.path.join(prefix,
-        'build', 'chmlib-0.40', 'src'))
-    chmlib_lib_dirs = consolidate('CHMLIB_LIB_DIR', os.path.join(prefix,
-        'build', 'chmlib-0.40', 'src', 'Release'))
+    chmlib_inc_dirs = [sw_inc_dir]
+    chmlib_lib_dirs = [sw_lib_dir]
     ft_lib_dirs = [sw_lib_dir]
     ft_libs = ['freetype']
     ft_inc_dirs = [os.path.join(sw_inc_dir, 'freetype2'), sw_inc_dir]
     zlib_inc_dirs = [sw_inc_dir]
     zlib_lib_dirs = [sw_lib_dir]
-
     podofo_inc = os.path.join(sw_inc_dir, 'podofo')
     podofo_lib = sw_lib_dir
 elif isosx:
-    QT_DLLS += ['Qt5DBus', 'Qt5MacExtras']
-    PYQT_MODULES += ('QtMacExtras',)
-    QT_FRAMEWORKS = [x.replace('5', '') for x in QT_DLLS]
     sw = os.environ.get('SW', os.path.expanduser('~/sw'))
     podofo_inc = os.path.join(sw, 'include', 'podofo')
     podofo_lib = os.path.join(sw, 'lib')
@@ -174,8 +141,6 @@ elif isosx:
     openssl_inc_dirs = [os.path.join(SSL, 'include')]
     openssl_lib_dirs = [os.path.join(SSL, 'lib')]
 else:
-    QT_DLLS += ['Qt5DBus', 'Qt5XcbQpa', 'Qt5X11Extras']
-    PYQT_MODULES += ('QtX11Extras',)
     ft_inc_dirs = pkgconfig_include_dirs('freetype2', 'FT_INC_DIR',
             '/usr/include/freetype2')
     ft_lib_dirs = pkgconfig_lib_dirs('freetype2', 'FT_LIB_DIR', '/usr/lib')
@@ -195,8 +160,3 @@ podofo_error = None if os.path.exists(os.path.join(podofo_inc, 'podofo.h')) else
     ' functionality will not work. Use the PODOFO_INC_DIR and',
     ' PODOFO_LIB_DIR environment variables.')
 podofo_inc = [podofo_inc, os.path.dirname(podofo_inc)]
-
-BUILD_HOST='192.168.81.1'
-PROJECT=os.path.basename(os.path.abspath('.'))
-
-
